@@ -8,3 +8,8 @@ from .license import LicenseManager, License
 from .book import BookManager, Book
 from .bookpart import BookPartManager, BookPart
 from .post import PostManager, Post
+from .comment import CommentManager, Comment
+from .rating import Rating, PostRatingManager, PostRating, CommentRatingManager, CommentRating
+from .like import Like, PostLikeManager, PostLike, CommentLikeManager, CommentLike
+
+
