@@ -2,7 +2,7 @@ from django.core.validators import MaxValueValidator, MinValueValidator
 from django.db import models
 from django.utils.translation import gettext_lazy as _
 
-from . import Member, BaseModel, Post
+from . import Member, BaseModel, Post, Comment
 
 
 class Rating(models.Model):
@@ -41,4 +41,15 @@ class PostRating(BaseModel, Rating):
     objects = PostRatingManager()
 
 
+class CommentRatingManager(models.Manager):
+    pass
+
+
+class CommentRating(BaseModel, Rating):
+    comment = models.ForeignKey(
+        to=Comment,
+        on_delete=models.CASCADE
+    )
+    objects = CommentRatingManager()
+
 
